pub enum ParameterError {
OutOfRange {
parameter: String,
value: String,
min: String,
max: String,
reason: String,
},
InvalidValue {
parameter: String,
reason: String,
},
Missing {
parameter: String,
},
InvalidConfiguration {
operation: String,
reason: String,
},
}Expand description
Errors related to invalid parameters, ranges, or configuration values.
This covers validation failures for user-provided parameters to audio processing operations, including range violations and invalid configurations.
Variants
OutOfRange
A parameter value is outside the valid range for the operation.
Fields
InvalidValue
A parameter has an invalid value that doesn’t meet operation requirements.
Fields
Missing
Required parameters are missing or empty.
InvalidConfiguration
A configuration object contains conflicting or invalid settings.
Implementations
Sourceimpl ParameterError
impl ParameterError
Sourcepub fn out_of_range<P, V, Min, Max, R>(
parameter: P,
value: V,
min: Min,
max: Max,
reason: R,
) -> Self
pub fn out_of_range<P, V, Min, Max, R>( parameter: P, value: V, min: Min, max: Max, reason: R, ) -> Self
Create a new out-of-range parameter error.
Sourcepub fn invalid_value<P, R>(parameter: P, reason: R) -> Self
pub fn invalid_value<P, R>(parameter: P, reason: R) -> Self
Create a new invalid value parameter error.